@@ -1,6 +1,7 @@
-# Copyright 2021 UW-IT, University of Washington
+# Copyright 2022 UW-IT, University of Washington
 # SPDX-License-Identifier: Apache-2.0
 
+
 from restclients_core import models
 import dateutil.parser
 import re
@@ -124,6 +125,8 @@ class CanvasCourse(models.Model):
     name = models.CharField(max_length=200)
     course_url = models.CharField(max_length=2000)
     workflow_state = models.CharField(max_length=50)
+    is_public = models.NullBooleanField()
+    is_public_to_auth_users = models.NullBooleanField()
     public_syllabus = models.NullBooleanField()
     syllabus_body = models.TextField(null=True)
     grading_standard_id = models.IntegerField(null=True)
@@ -141,6 +144,8 @@ class CanvasCourse(models.Model):
         self.code = data["course_code"]
         self.name = data["name"]
         self.workflow_state = data["workflow_state"]
+        self.is_public = data["is_public"]
+        self.is_public_to_auth_users = data["is_public_to_auth_users"]
         self.public_syllabus = data["public_syllabus"]
         self.grading_standard_id = data.get("grading_standard_id")
 
@@ -264,15 +269,21 @@ class CanvasEnrollment(models.Model):
     TA = "TaEnrollment"
     OBSERVER = "ObserverEnrollment"
     DESIGNER = "DesignerEnrollment"
+    GUEST_TEACHER = "Guest Teacher"
+    LIBRARIAN = "Librarian"
+    OTHER_FACULTY = "Other Faculty"
+    PROGRAM_STAFF = "Program Staff"
 
     ROLE_CHOICES = (
         (STUDENT, "Student"),
         (TEACHER, "Teacher"),
         (TA, "TA"),
         (OBSERVER, "Observer"),
-        (DESIGNER, "Designer")
+        (DESIGNER, "Designer"),
     )
 
+    CUSTOM_ROLES = [GUEST_TEACHER, LIBRARIAN, OTHER_FACULTY, PROGRAM_STAFF]
+
     STATUS_ACTIVE = "active"
     STATUS_INVITED = "invited"
     STATUS_PENDING = "creation_pending"
@@ -296,7 +307,8 @@ class CanvasEnrollment(models.Model):
     section_id = models.IntegerField()
     login_id = models.CharField(max_length=80, null=True)
     sis_user_id = models.CharField(max_length=100, null=True)
-    role = models.CharField(max_length=80, choices=ROLE_CHOICES)
+    role = models.CharField(max_length=80)
+    base_role_type = models.CharField(max_length=80, choices=ROLE_CHOICES)
     status = models.CharField(max_length=100, choices=STATUS_CHOICES)
     name = models.CharField(max_length=100)
     sortable_name = models.CharField(max_length=100)
@@ -322,6 +334,7 @@ class CanvasEnrollment(models.Model):
     override_grade = models.TextField(max_length=12, null=True)
     grade_html_url = models.CharField(max_length=1000)
     total_activity_time = models.IntegerField(null=True)
+    created_at = models.DateTimeField(null=True)
     last_activity_at = models.DateTimeField(null=True)
     limit_privileges_to_course_section = models.NullBooleanField()
 
@@ -337,10 +350,13 @@ class CanvasEnrollment(models.Model):
         self.sis_course_id = data.get("sis_course_id")
         self.sis_section_id = data.get("sis_section_id")
         self.sis_user_id = data.get("sis_user_id")
-        self.role = data["type"]
+        self.role = data["role"]
+        self.base_role_type = data["type"]
         self.status = data["enrollment_state"]
         self.html_url = data["html_url"]
         self.course_url = self.get_course_url(self.html_url)
+        if data.get("created_at"):
+            self.created_at = dateutil.parser.parse(data["created_at"])
 
         self.total_activity_time = data["total_activity_time"]
         self.limit_privileges_to_course_section = data.get(
@@ -384,6 +400,8 @@ class CanvasEnrollment(models.Model):
         for base, name in CanvasEnrollment.ROLE_CHOICES:
             if role.lower() == base.lower() or role.lower() == name.lower():
                 return name.lower()
+        if role in CanvasEnrollment.CUSTOM_ROLES:
+            return role
 
     def json_data(self):
         return {"user_id": self.user_id,
@@ -394,6 +412,7 @@ class CanvasEnrollment(models.Model):
                 "login_id": self.login_id,
                 "sis_user_id": self.sis_user_id,
                 "role": self.role,
+                "base_role_type": self.base_role_type,
                 "status": self.status,
                 "current_score": self.current_score,
                 "current_grade": self.current_grade,
@@ -749,7 +768,7 @@ class Quiz(models.Model):
         self.html_url = data["html_url"]
         self.published = data["published"]
         self.points_possible = data["points_possible"]
-        if "due_at" in data and "due_at" is not None:
+        if "due_at" in data and data["due_at"] is not None:
             self.due_at = dateutil.parser.parse(data["due_at"])
 
 
