@@ -1,6 +1,7 @@
-# Copyright 2021 UW-IT, University of Washington
+# Copyright 2022 UW-IT, University of Washington
 # SPDX-License-Identifier: Apache-2.0
 
+
 from unittest import TestCase
 from commonconf import override_settings
 from uw_canvas.utilities import fdao_canvas_override
@@ -162,7 +163,9 @@ class CanvasTestUsers(TestCase):
             user.sortable_name, "AVERAGE, JAMES", "Sortable Name")
         enrollment = user.enrollments[0]
         self.assertEquals(enrollment.sis_course_id, "2015-summer-TRAIN-100-A")
-        self.assertEquals(enrollment.role, "DesignerEnrollment", "Role")
+        self.assertEquals(enrollment.role, "Librarian", "Role")
+        self.assertEquals(
+            enrollment.base_role_type, "DesignerEnrollment", "Base Role Type")
 
     def test_get_logins(self):
         canvas = Users()
@@ -221,6 +224,14 @@ class CanvasTestUsers(TestCase):
         canvas.delete_user_login(login)
         mock_delete.assert_called_with('/api/v1/users/188885/logins/100')
 
+    @mock.patch.object(Users, '_delete_resource')
+    def test_terminate_sessions(self, mock_delete):
+        canvas = Users()
+
+        user_id = 188885
+        canvas.terminate_user_sessions(user_id)
+        mock_delete.assert_called_with('/api/v1/users/188885/sessions')
+
     @mock.patch.object(Users, '_get_resource_url')
     def test_get_page_views(self, mock_get):
         canvas = Users()
