@@ -1,6 +1,7 @@
-# Copyright 2021 UW-IT, University of Washington
+# Copyright 2022 UW-IT, University of Washington
 # SPDX-License-Identifier: Apache-2.0
 
+
 from uw_canvas import Canvas, MissingAccountID
 from uw_canvas.accounts import ACCOUNTS_API
 from uw_canvas.courses import COURSES_API
@@ -138,3 +139,7 @@ class Users(Canvas):
         return self.get_user_page_views(
             self._sis_id(sis_login_id, sis_field="login"),
             start_time=start_time, end_time=end_time)
+
+    def terminate_user_sessions(self, user_id):
+        url = USERS_API.format(user_id) + "/sessions"
+        return self._delete_resource(url)
